
# Type: chemical to thing association_subject




URI: [biolink:chemical_to_thing_association_subject](https://w3id.org/biolink/vocab/chemical_to_thing_association_subject)


## Domain and Range

[ChemicalToThingAssociation](ChemicalToThingAssociation.md) ->  <sub>REQ</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ChemicalToThingAssociation](ChemicalToThingAssociation.md)
